@@ -53,14 +53,8 @@
 #include "xmlencodinghandler.h"
 #include "myipc.h"
 #include "xmlcopyeditorcopy.h"
-#include "mytoolbar.h"
-#include "mymenubar.h"
 #include <wx/aui/framemanager.h>
 
-#ifdef __WXMSW__
-#include "wxcoolbar.h"
-#endif
-
 enum
 {
     STATUS_HIDDEN = 1,
@@ -104,8 +98,13 @@ enum
     ID_NOTEBOOK_STYLE_VC8_COLOR,
     ID_DOWNLOAD_SOURCE,
     ID_OPEN_LARGE_FILE,
+    ID_RELOAD,
     ID_WRAP_WORDS,
     // IDs to be activated only if a document is open
+    ID_SPLIT_TAB_TOP,
+    ID_SPLIT_TAB_RIGHT,
+    ID_SPLIT_TAB_BOTTOM,
+    ID_SPLIT_TAB_LEFT,
     ID_FIND,
     ID_FIND_AGAIN,
     ID_GOTO,
@@ -228,6 +227,7 @@ public:
     void OnGlobalReplace ( wxCommandEvent& event );
     void OnWordCount ( wxCommandEvent& event );
     void OnFeedback ( wxCommandEvent& event );
+    void OnSplitTab ( wxCommandEvent& event );
     void OnFontSmaller ( wxCommandEvent& event );
     void OnFontMedium ( wxCommandEvent& event );
     void OnFontLarger ( wxCommandEvent& event );
@@ -249,6 +249,7 @@ public:
     void OnQuit ( wxCommandEvent& event );
     void OnSave ( wxCommandEvent& event );
     void OnSaveAs ( wxCommandEvent& event );
+    void OnReload ( wxCommandEvent& event );
     void OnUndo ( wxCommandEvent& event );
     void OnRedo ( wxCommandEvent& event );
     void OnSpelling ( wxCommandEvent& event );
@@ -273,6 +274,7 @@ public:
     void OnUpdatePaste ( wxUpdateUIEvent& event );
     void OnUpdateDocRange ( wxUpdateUIEvent& event );
     void OnUpdateReplaceRange ( wxUpdateUIEvent& event );
+    void OnUpdateReload ( wxUpdateUIEvent& event );
     void OnUpdateLocationPaneVisible ( wxUpdateUIEvent& event );
     void OnValidateDTD ( wxCommandEvent& event );
     void OnValidateRelaxNG ( wxCommandEvent& event );
@@ -324,12 +326,15 @@ public:
     void statusProgress ( const wxString& s );
 
     // public to allow InsertPanel access
-    void messagePane ( const wxString& s, int iconType = CONST_INFO );
+    void messagePane ( const wxString& s,
+        int iconType = CONST_INFO,
+        bool forcePane = false );
 
     // public to allow IPC access
     bool openFile ( wxString& fileName, bool largeFile = false );
     bool isOpen ( const wxString& fileName );
-    void activateTab ( const wxString& fileName );
+    bool activateTab ( const wxString& fileName );
+    void reloadTab();
 private:
     wxAuiManager manager;
     wxConfig *config; // owned by MyApp
@@ -342,8 +347,8 @@ private:
     std::auto_ptr<wxHtmlHelpController> helpController;
 
     wxBoxSizer *frameSizer;
-    MyMenuBar *menuBar;
-    MyToolBar *toolBar;
+    wxMenuBar *menuBar;
+    wxToolBar *toolBar;
     LocationPanel *locationPanel;
     InsertPanel *insertChildPanel, *insertSiblingPanel, *insertEntityPanel;
 
@@ -404,8 +409,6 @@ private:
     lastParent,
     lastGrandparent,
     commandString;
-    //wxTextCtrl *stderrControl;
-    //wxStreamToTextRedirector *redirector;
     bool globalReplaceAllDocuments,
     toolbarVisible,
     protectTags,
@@ -456,13 +459,12 @@ private:
     internetBitmap,
     internetGrBitmap,
     hyperlinkBitmap,
-    filtersBitmap;
+    filtersBitmap,
+    checkWellformedBitmap,
+    checkValidBitmap;
     wxFileHistory history;
     wxFindReplaceData findData;
     XmlCtrlProperties properties, largeFileProperties;
-#ifdef __WXMSW__
-    wxCoolBar *coolBar;
-#endif
 
     // member functions
     bool panelHasFocus();
@@ -470,7 +472,6 @@ private:
         XmlDoc *doc,
         wxString& fileName,
         bool checkLastModified = true );
-    bool xpThemeActive();
     int getFileType ( const wxString& fileName );
     long getNotebookStyleMask();
     wxString getLinuxBrowser();
@@ -502,8 +503,8 @@ private:
         bool isXml = true );
     void removeUtf8Bom ( std::string& buffer );
     std::string getAuxPath ( const std::string& fileName );
-    MyMenuBar *getMenuBar();
-    MyToolBar *getToolBar();
+    wxMenuBar *getMenuBar();
+    wxToolBar *getToolBar();
 
     DECLARE_EVENT_TABLE()
 };
