@@ -59,8 +59,8 @@ XmlCtrl::XmlCtrl (
         basePath ( basePathParameter ),
         auxPath ( auxPathParameter )
 {
-    SetEOLMode ( wxSTC_EOL_LF );
-    SetPasteConvertEndings ( true ); // essential to avoid double-spaced paste
+    //SetEOLMode ( wxSTC_EOL_LF );
+    //SetPasteConvertEndings ( true );
 
     currentMaxLine = 1;
     validationRequired = dtdFound = false;
@@ -1728,8 +1728,25 @@ void XmlCtrl::toggleFold()
         return;
     line = LineFromPosition ( pos );
     level = GetFoldLevel ( line );
-    if ( XMLCTRL_HASBIT ( level, wxSTC_FOLDLEVELHEADERFLAG ) )
-        ToggleFold ( line );
+
+    for ( int iterator = line; iterator > 0; iterator--)
+    {
+      if (iterator != line)
+      {
+        GotoLine ( iterator );
+	level = GetFoldLevel ( iterator );
+      }
+
+      if ( XMLCTRL_HASBIT ( level, wxSTC_FOLDLEVELHEADERFLAG ) )
+      {
+        ToggleFold ( iterator );
+        break;
+      }
+    }
+         
+// was previously (changed so cursor doesn't have to be in headline):
+//    if ( XMLCTRL_HASBIT ( level, wxSTC_FOLDLEVELHEADERFLAG ) )
+//        ToggleFold ( line );
 }
 
 // adapted from wxSTEdit (c) 2005 John Labenski, Otto Wyss
@@ -1969,7 +1986,7 @@ bool XmlCtrl::shallowValidate ( int maxLine, bool segmentOnly )
         parentStartAngleBracket,
         memory;
         current = GetCurrentPos();
-        line = LineFromPosition ( current );//PositionFromLine(current);
+        line = LineFromPosition ( current );
 
         // try to include next line
         lineEnd = GetLineEndPosition ( line + 1 );
@@ -2022,29 +2039,6 @@ bool XmlCtrl::shallowValidate ( int maxLine, bool segmentOnly )
 
     return shallowValidate ( bufferUtf8.c_str(), bufferUtf8.size(), startLine,
                              maxLine, columnOffset, segmentOnly );
-    /*
-      bool res = validator->parse(bufferUtf8, (segmentOnly) ? false : true);
-      if (!validator->getOverrideFailure() && (!res || !validator->isValid()))
-      {
-        std::vector<std::pair<int, int> > positionVector = validator->getPositionVector();
-
-        if (res == XML_STATUS_ERROR)
-        {
-          positionVector.push_back(validator->getErrorPosition());
-        }
-
-        std::vector<std::pair<int, int> >::iterator it;
-        for (it = positionVector.begin(); it != positionVector.end(); it++)
-        {
-          int line, column;
-          line = (it->first - 1) + startLine;
-          column = it->second + columnOffset;
-          setErrorIndicator(line, column);
-        }
-        return false;
-      }
-      return true;
-    */
 }
 
 bool XmlCtrl::shallowValidate ( const char *buffer,
@@ -2119,7 +2113,7 @@ void XmlCtrl::setErrorIndicator ( int line, int column )
 
 void XmlCtrl::clearErrorIndicators ( int maxLine )
 {
-    if ( maxLine < 1 )
+    if ( maxLine < 0 )
         return;
 
     int documentLength = GetLength();
